<?php 
/*
Plugin Name: Simple G Translate Button
Plugin URI: https://starvizion.in/
Author: Star Vizion
Author URI: https://starvizion.in/
Description: Adds a Google Language Translate button to your site. Use the shortcode [google_translate] in posts, pages, or theme files.
Version: 1.0.2
License: GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: simple-g-translate-button
*/



// Enqueue Google Translate script
function gt_enqueue_google_translate_script() {
    wp_enqueue_script('google-translate', '//translate.google.com/translate_a/element.js?cb=googleTranslateElementInit', array(), null, true);
}
add_action('wp_enqueue_scripts', 'gt_enqueue_google_translate_script');

// Initialize Google Translate
function gt_google_translate_init_script() {
    ?>
    <script type="text/javascript">
        function googleTranslateElementInit() {
            new google.translate.TranslateElement({
                pageLanguage: 'en',
                autoDisplay: true
            }, 'google_translate_element');
        }
    </script>
    <?php
}
add_action('wp_footer', 'gt_google_translate_init_script');

// Shortcode to display Google Translate element
function gt_google_translate_shortcode() {
    return '<div id="google_translate_element"></div>';
}
add_shortcode('google_translate', 'gt_google_translate_shortcode');

// Show admin notice with usage instructions on plugin activation
function gt_admin_notice() {
    ?>
    <div class="notice notice-success is-dismissible">
        <p><strong>Simple G Language Translate Button activated!</strong> Use the shortcode <code>[google_translate]</code> in any post, page, or widget to add the translation button. To place it directly in a theme template, use <code>&lt;?php echo do_shortcode('[google_translate]'); ?&gt;</code>.</p>
    </div>
    <?php
}
add_action('admin_notices', 'gt_admin_notice');

// Add a settings page under Settings > Google Translate
function gt_add_settings_page() {
    add_options_page(
        'Google Translate Instructions', // Page title
        'Google Translate',              // Menu title
        'manage_options',                // Capability required
        'google-translate-instructions', // Menu slug
        'gt_render_settings_page'        // Callback function
    );
}
add_action('admin_menu', 'gt_add_settings_page');

// Render the settings page
function gt_render_settings_page() {
    ?>
    <div class="wrap">
        <h1>Google Translate Plugin Instructions</h1>
        <p>Use the following shortcode to add the Google Translate button anywhere on your site:</p>
        <code>[google_translate]</code>
        <p>You can place it in posts, pages, or text widgets. To place it directly in a theme template, use the following PHP code:</p>
        <code>&lt;?php echo do_shortcode('[google_translate]'); ?&gt;</code>
    </div>
    <?php
}
?>